[initial-setup][master][PATCH] Use /usr/bin/python2

Martin Kolman mkolman at redhat.com
Mon Feb 9 16:34:29 UTC 2015


Comply with the new packaging guidelines:

https://fedoraproject.org/wiki/Packaging:Python#Multiple_Python_Runtimes
https://fedorahosted.org/fpc/ticket/327#comment:9
Signed-off-by: Martin Kolman <mkolman at redhat.com>
---
 setup.py                  | 2 +-
 tests/pylint/runpylint.sh | 4 ++--
 2 files changed, 3 insertions(+), 3 deletions(-)

diff --git a/setup.py b/setup.py
index 978b9fd..7252c30 100644
--- a/setup.py
+++ b/setup.py
@@ -1,4 +1,4 @@
-#!/usr/bin/python
+#!/usr/bin/python2
 # Setup file for initial-setup
 #
 # Copyright (C) 2012  Red Hat, Inc.
diff --git a/tests/pylint/runpylint.sh b/tests/pylint/runpylint.sh
index 18200bf..f410e26 100755
--- a/tests/pylint/runpylint.sh
+++ b/tests/pylint/runpylint.sh
@@ -92,10 +92,10 @@ fi
 # run pylint one file / module at a time, otherwise it sometimes gets
 # confused
 if [ -z "$FILES" ]; then
     # Test any file that either ends in .py or contains #!/usr/bin/python in
     # the first line.  Scan everything except old_tests
     FILES=$(findtestfiles \( -name '*.py' -o \
-                -exec /bin/sh -c "head -1 {} | grep -q '#!/usr/bin/python'" \; \) -print | \
+                -exec /bin/sh -c "head -1 {} | grep -q '#!/usr/bin/python2'" \; \) -print | \
             egrep -v '(|/)doc/conf.py')
 fi
 
@@ -92,10 +92,10 @@ fi
 # confused
 if [ -z "$FILES" ]; then
-    # Test any file that either ends in .py or contains #!/usr/bin/python in
+    # Test any file that either ends in .py or contains #!/usr/bin/python2 in
     # the first line.  Scan everything except old_tests
     FILES=$(findtestfiles \( -name '*.py' -o \
-- 
2.1.0



More information about the anaconda-patches mailing list